def window_fullscreen(driver: object) -> None:
    driver.fullscreen_window()  # type: ignore
